.. _tutorials:

=========
Tutorials
=========

Tutorials are the best place to start for anyone new to SymPy or one of SymPy's
features.

:ref:`Introductory Tutorial <intro-tutorial>`
=============================================

If you are new to SymPy, start here.

.. toctree::
   :hidden:

   intro-tutorial/index.rst

Biomechanics Tutorials
======================

.. toctree::
   :hidden:

   biomechanics/biomechanics.rst
   biomechanics/biomechanical-model-example.rst

- :ref:`Introduction to Biomechanical Modeling <biomechanics-tutorial>`
- :ref:`Biomechanical Model Example <biomechanical-model-example>`
